api.world.v1 package — Argus-Toolbelt 1.0 documentation

# api.world.v1 package

## Submodules

## api.world.v1.timezone module

Autogenerated API

`api.world.v1.timezone.` `get_time_zones`(keywords: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get all time zones (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Filter time zones by keywords offset (int) – Skip a number of time zones limit (int) – Maximum number of returned time zones
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 354, “limit”: 635, “responseCode”: 200, “count”: 748, “data”: [{“description”: “Check body grow all message.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “East learn meet to law.”, “messageTemplate”: “She blood whether capital.”, “field”: “Among fund power home blood customer.”, “parameter”: {}, “timestamp”: 633676492}], “currentPage”: 871, “size”: 478}

## Module contents